django-autoresponse-middleware
======
...

### Install
```pip install django-autoresponse-middleware```


### Usage
```python
...
```

----
[![Coverage Status](https://coveralls.io/repos/github/dpep/django-autoresponse-middleware/badge.svg?branch=main)](https://coveralls.io/github/dpep/django-autoresponse-middleware?branch=main)
[![installs](https://img.shields.io/pypi/dm/django-autoresponse-middleware?label=installs)](https://pypi.org/project/django-autoresponse-middleware)
